<!-- Adjust DocBook 4.5 tags before converting to 'docx'
using pandoc. -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:template match="@* | node()">
    <xsl:copy>
      <xsl:apply-templates select="@* | node()"/>
    </xsl:copy>
  </xsl:template>
  <!-- prefaces are ignored by pandoc so change to a chapter -->
  <xsl:template match="preface">
    <!-- root can only be a book or a part -->
    <chapter>
      <xsl:apply-templates select="@*|node()"/>
    </chapter>
  </xsl:template>
  <!-- remove tags inside screen, programlisting -->
  <xsl:template match="emphasis | option | replaceable ">
    <xsl:choose>
      <xsl:when test="(name(parent::*) = 'screen'
                    or name(parent::*) = 'programlisting'
                    or name(parent::*) = 'command'
                    or name(parent::*) = 'code')">
        <xsl:apply-templates select="node()"/>
      </xsl:when>
      <xsl:otherwise>
        <!-- add spaces, issue with pandoc and proximate (inline) tags -->
        <emphasis>
          <xsl:apply-templates select="@*|node()"/>
        </emphasis>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <!-- Convert _internal_ links to bolded text
  since pandoc cannot do anything with them.
  All xrefs have already been converted to links
  by the PHP script. -->
  <xsl:template match="link[@linkend!='']">
    <!-- add spaces, issue with pandoc and proximate (inline) tags -->
    <emphasis role="bold">
      <xsl:value-of select="./text()"/>
    </emphasis>
  </xsl:template>
  <!-- change inline glossterm to emphasis -->
  <xsl:template match="glossterm">
    <xsl:choose>
      <xsl:when test="(name(parent::*) = 'glossentry')">
        <glossterm>
          <xsl:apply-templates select="@*|node()"/>
        </glossterm>
      </xsl:when>
      <xsl:otherwise> 
        <!-- change inline to emphasis -->
        <emphasis>
          <xsl:apply-templates select="@*|node()"/>
        </emphasis>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <!-- literal treated as verbatim, change to phrase -->
  <xsl:template match="literal">
    <!-- add spaces, issue with pandoc and proximate (inline) tags -->
    <!--xsl:text>  </xsl:text-->
    <phrase role="literal"><xsl:apply-templates select="@*|node()"/></phrase>
    <!--xsl:text>  </xsl:text-->
  </xsl:template>
  <!-- convert userinput, command, etc to emphasis -->
  <xsl:template match="userinput 
                     | keycap 
                     | command
                     | code
                     | sgmltag
                     | guibutton
                     | guilabel
                     | guiicon
                     | guimenu
                     | guimenitem
                     | guisubmenu">
    <!-- add spaces, issue with pandoc and proximate (inline) tags -->
    <emphasis>
      <xsl:apply-templates/>
    </emphasis>
  </xsl:template>
  
  <xsl:template match="filename">
    <emphasis role="bold">
      <xsl:apply-templates select="@*|node()"/>
    </emphasis>
  </xsl:template>
  <!-- convert title to bridgehead, capture id.
   Do this for figures, examples and sidebars. -->
  <xsl:template match="title">
    <xsl:choose>
      <xsl:when test="(name(parent::*) = 'blockinfo')
                  and (name(../..) = 'figure' 
                    or name(../..) = 'example'
                    or name(../..) = 'sidebar')">
        <bridgehead>
          <!-- check that there is an id first! -->
          <xsl:choose>
            <xsl:when test="../../@id">
              <xsl:attribute name="id">
                <!-- id will be grandparent -->
                <xsl:value-of select="../../@id"/>
              </xsl:attribute>
            </xsl:when>
            <xsl:otherwise><!-- do nothing --></xsl:otherwise>
          </xsl:choose>
          <xsl:apply-templates select="@* "/>
          <xsl:apply-templates select="node()"/>
        </bridgehead>
      </xsl:when>
      <xsl:when test="name(parent::*) = 'figure'
                   or name(parent::*) = 'example'
                   or name(parent::*) = 'sidebar'
                   or name(parent::*) = 'abstract'">
        <bridgehead>
          <xsl:choose>
            <!-- if there's an id, capture it -->
            <xsl:when test="../@id">
              <xsl:attribute name="id">
                <xsl:value-of select="../@id"/>
              </xsl:attribute>
            </xsl:when>
            <xsl:otherwise><!-- do nothing --></xsl:otherwise>
          </xsl:choose>
          <xsl:apply-templates select="@* "/>
          <xsl:apply-templates select="node()"/>
        </bridgehead>
      </xsl:when>
      <!-- remove title from <table> (making all tables
      <informaltables>) -->
      <xsl:when test="name(parent::*) = 'blockinfo'
                  and name(../..) = 'table' ">
        <!-- do nothing -->
      </xsl:when>
      <xsl:when test="name(parent::*) = 'table'">
        <!-- do nothing -->
      </xsl:when>
      <xsl:otherwise>
        <title>
          <xsl:apply-templates select="@* "/>
          <xsl:apply-templates select="node()"/>
        </title>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <!-- convert table to informaltable -->
  <xsl:template match="table">
    <informaltable>
      <xsl:apply-templates select="@* "/>
      <xsl:apply-templates select="node()"/>
    </informaltable>
  </xsl:template>  
  <!-- Convert simplesect to a section -->
  <xsl:template match="simplesect">
    <section>
      <xsl:apply-templates select="@* | node()"/>
    </section>
  </xsl:template>
  <!-- Convert calloutlist to an ordered list -->
  <xsl:template match="calloutlist">
    <orderedlist>
      <xsl:apply-templates select="@* | node()"/>
    </orderedlist>
  </xsl:template>
  <xsl:template match="callout">
    <listitem>
      <xsl:apply-templates select="node()"/>
    </listitem>
  </xsl:template>
  <!-- remove co tag but keep text -->
  <xsl:template match="co">
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <!-- get rid of tag -->
  <xsl:template match="sectioninfo
                     | figure 
                     | example
                     | sidebar
                     | blockinfo
                     | chapterinfo
                     | appendixinfo
                     | refsectioninfo
                     | prefaceinfo
                     | glossaryinfo">
    <xsl:apply-templates/>
  </xsl:template>
  <!-- get rid of entirely -->
  <xsl:template match="keywordset
                     | authorblurb
                     | remark
                     | indexterm"/>
  <xsl:output method="xml" indent="yes"
    doctype-public="-//OASIS//DTD DocBook XML V4.5//EN"
    doctype-system="http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd"/>
</xsl:stylesheet>
